package buildcraft.lib.client.guide.loader.entry;

import java.util.List;

import javax.annotation.Nullable;

import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;
import net.minecraft.util.ResourceLocation;

import net.minecraftforge.fml.common.registry.ForgeRegistries;

import buildcraft.lib.client.guide.loader.MarkdownPageLoader;
import buildcraft.lib.gui.GuiStack;
import buildcraft.lib.gui.ISimpleDrawable;
import buildcraft.lib.misc.GuiUtil;
import buildcraft.lib.misc.ItemStackKey;

public class EntryTypeItem extends PageEntryType<ItemStackValueFilter> {

    public static final String ID = "minecraft:item_stack";
    public static final EntryTypeItem INSTANCE = new EntryTypeItem();

    @Override
    @Nullable
    public ItemStackValueFilter deserialise(String source) {
        final ItemStack stack;
        final boolean matchMeta;
        final boolean matchNbt;
        if (source.startsWith("{") && source.endsWith("}")) {
            stack = MarkdownPageLoader.loadComplexItemStack(source.substring(1, source.length() - 1));
            stack.func_190920_e(1);
            matchMeta = true;
            matchNbt = stack.func_77942_o();
        } else {
            if (source.startsWith("(") && source.endsWith(")")) {
                source = source.substring(1, source.length() - 1);
            }
            Item item = ForgeRegistries.ITEMS.getValue(new ResourceLocation(source));
            if (item == null) {
                return null;
            }
            stack = new ItemStack(item);
            matchMeta = false;
            matchNbt = false;
        }
        if (stack.func_190926_b()) {
            return null;
        }
        return new ItemStackValueFilter(new ItemStackKey(stack), matchMeta, matchNbt);
    }

    @Override
    public List<String> getTooltip(ItemStackValueFilter value) {
        return GuiUtil.getFormattedTooltip(value.stack.baseStack);
    }

    @Override
    public boolean matches(ItemStackValueFilter target, Object value) {
        if (value instanceof ItemStackKey) {
            value = ((ItemStackKey) value).baseStack;
        }
        if (value instanceof ItemStack) {
            ItemStack base = target.stack.baseStack;
            ItemStack test = (ItemStack) value;
            if (base.func_190926_b() || test.func_190926_b()) {
                return false;
            }
            if (base.func_77973_b() != test.func_77973_b()) {
                return false;
            }
            if (target.matchMeta) {
                if (base.func_77960_j() != test.func_77960_j()) {
                    return false;
                }
            }
            if (target.matchNbt) {
                if (!ItemStack.func_77970_a(base, test)) {
                    return false;
                }
            }
            return true;
        }
        return false;
    }

    @Override
    @Nullable
    public ISimpleDrawable createDrawable(ItemStackValueFilter value) {
        return new GuiStack(value.stack.baseStack);
    }
}
