package buildcraft.lib.gui;

import java.io.IOException;
import java.util.function.Function;

import net.minecraft.client.gui.GuiScreen;
import net.minecraft.util.ResourceLocation;

import buildcraft.lib.gui.json.BuildCraftJsonGui;
import buildcraft.lib.gui.ledger.LedgerHelp;
import buildcraft.lib.gui.pos.IGuiArea;
import buildcraft.lib.misc.GuiUtil;

/** Reference implementation for a gui that delegates to a {@link BuildCraftGui} for most of its functionality. */
public class GuiScreenBuildCraft extends GuiScreen {

    public final BuildCraftGui mainGui;

    /** Creates a new {@link GuiScreenBuildCraft} that will occupy the entire screen. */
    public GuiScreenBuildCraft() {
        this(g -> new BuildCraftGui(g));
    }

    /** Creates a new {@link GuiScreenBuildCraft} that will occupy the given {@link IGuiArea} Call
     * {@link GuiUtil#moveAreaToCentre(IGuiArea)} if you want a centred gui. (Ignoring ledgers, which will display off
     * to the side) */
    public GuiScreenBuildCraft(IGuiArea area) {
        this(g -> new BuildCraftGui(g, area));
    }

    public GuiScreenBuildCraft(Function<GuiScreenBuildCraft, BuildCraftGui> constructor) {
        this.mainGui = constructor.apply(this);
        standardLedgerInit();
    }

    /** Creates a new gui that will load its elements from the given json resource. */
    public GuiScreenBuildCraft(ResourceLocation jsonGuiDef) {
        BuildCraftJsonGui jsonGui = new BuildCraftJsonGui(this, jsonGuiDef);
        this.mainGui = jsonGui;
        standardLedgerInit();
    }

    /** Creates a new gui that will load its elements from the given json resource. Like
     * {@link #GuiScreenBuildCraft(IGuiArea)} this will occupy only the given {@link IGuiArea} */
    public GuiScreenBuildCraft(ResourceLocation jsonGuiDef, IGuiArea area) {
        BuildCraftJsonGui jsonGui = new BuildCraftJsonGui(this, area, jsonGuiDef);
        this.mainGui = jsonGui;
        standardLedgerInit();
    }

    private final void standardLedgerInit() {
        if (shouldAddHelpLedger()) {
            mainGui.shownElements.add(new LedgerHelp(mainGui, false));
        }
    }

    protected boolean shouldAddHelpLedger() {
        return true;
    }

    @Override
    public void func_73863_a(int mouseX, int mouseY, float partialTicks) {
        mainGui.drawBackgroundLayer(partialTicks, mouseX, mouseY, this::drawMenuBackground);
        mainGui.drawElementBackgrounds();
        mainGui.drawElementForegrounds(this::drawMenuBackground);
    }

    private void drawMenuBackground() {
        this.func_146278_c(0);
    }

    @Override
    protected void func_73864_a(int mouseX, int mouseY, int mouseButton) throws IOException {
        if (!mainGui.onMouseClicked(mouseX, mouseY, mouseButton)) {
            super.func_73864_a(mouseX, mouseY, mouseButton);
        }
    }

    @Override
    protected void func_146286_b(int mouseX, int mouseY, int state) {
        super.func_146286_b(mouseX, mouseY, state);
        mainGui.onMouseReleased(mouseX, mouseY, state);
    }

    @Override
    protected void func_146273_a(int mouseX, int mouseY, int clickedMouseButton, long timeSinceLastClick) {
        super.func_146273_a(mouseX, mouseY, clickedMouseButton, timeSinceLastClick);
        mainGui.onMouseDragged(mouseX, mouseY, clickedMouseButton, timeSinceLastClick);
    }

    @Override
    protected void func_73869_a(char typedChar, int keyCode) throws IOException {
        if (!mainGui.onKeyTyped(typedChar, keyCode)) {
            super.func_73869_a(typedChar, keyCode);
        }
    }
}
